//
//  Appclicks.h
//  Appclicks Library
//
//  Copyright 2009-2012 Appclicks LLC. All rights reserved.
//

#define ACSdkVersion @"3.0.0"
#define ACSdkCommit @"6b3cae4"

/**
 * Appclicks.h allows you to integrate Appclicks into your application.
 */

@interface Appclicks : NSObject {}

/**
 * This method is the only required method to initialize Appclicks. Usage information is sent now and periodically through the app's session. 
 * The SDK will only begin monitoring when tracking is enabled, so this method can be called regardless of the user's settings.
 * This method must be called before any other method, and it is a class call: [Appclicks init].
 * @return Boolean for whether Appclicks started successfully
 */
+ (BOOL)init;

/**
 * This method is an alternative way to initialize where the application can pass in a dictionary of properties to add to every event.
 * The dictionary must only contain NSStrings for both keys and values.
 * Otherwise, it's identical to +(BOOL)init. Read its description for more information.
 * @return Boolean for whether Appclicks started successfully
 */
+ (BOOL)initWithProperties:(NSDictionary *)properties;

/**
 * Is tracking enabled or disabled?
 * @return Boolean for whether tracking is enabled.
 */
+ (BOOL)isTrackingEnabled;

/**
 * The application can enable and disable tracking. Typically, the application would display a checkbox in Preference for this.
 * @param isTrackingEnabled Is tracking enabled?
 */
+ (void)setTrackingEnabled:(BOOL)isTrackingEnabled;

/**
 * Add an event for this application.
 * @param name A required NSString name for the event.
 */
+ (BOOL)addEvent:(NSString *)name;

/**
 * Add an event with properties for this application.
 * @param name A required NSString name for the event.
 * @param properties A required NSDictionary set of properties for the event. The dictionary must only contain NSStrings for both keys and values.
 */
+ (BOOL)addEvent:(NSString *)name withProperties:(NSDictionary *)properties;

/**
 * Add a property for this application.
 * @param name A required NSString name.
 * @param value A required NSString value.
 */
+ (BOOL)addProperty:(NSString *)name withValue:(NSString *)value;

@end
